@@ -146,7 +146,7 @@ DirFilterPlugin::DirFilterPlugin (TQObject* parent, const char* name,
                 :KParts::Plugin (parent, name),
                  m_oldFilterString("")
 {
-  m_part = ::tqqt_cast<KonqDirPart*>(parent);
+  m_part = ::tqt_cast<KonqDirPart*>(parent);
 
   if ( !m_part || !m_part->scrollWidget() )
     return;
@@ -156,18 +156,18 @@ DirFilterPlugin::DirFilterPlugin (TQObject* parent, const char* name,
   m_pFilterMenu->setDelayed (false);
   m_pFilterMenu->setWhatsThis(i18n("Allow to filter the currently displayed items by filetype."));
 
-  connect (m_pFilterMenu->popupMenu(), TQT_SIGNAL (aboutToShow()),
-           TQT_SLOT (slotShowPopup()));
+  connect (m_pFilterMenu->popupMenu(), TQ_SIGNAL (aboutToShow()),
+           TQ_SLOT (slotShowPopup()));
 
-  connect (m_part, TQT_SIGNAL(itemRemoved(const KFileItem*)),
-           TQT_SLOT( slotItemRemoved (const KFileItem*)));
-  connect (m_part, TQT_SIGNAL(itemsAdded(const KFileItemList&)),
-           TQT_SLOT (slotItemsAdded(const KFileItemList&)));
-  connect (m_part, TQT_SIGNAL(itemsFilteredByMime(const KFileItemList&)),
-           TQT_SLOT (slotItemsAdded(const KFileItemList&)));
-  connect (m_part, TQT_SIGNAL(itemsRefresh(const KFileItemList&)),
-           TQT_SLOT (slotItemsRefresh(const KFileItemList&)));
-  connect (m_part, TQT_SIGNAL(aboutToOpenURL()), TQT_SLOT(slotOpenURL()));
+  connect (m_part, TQ_SIGNAL(itemRemoved(const KFileItem*)),
+           TQ_SLOT( slotItemRemoved (const KFileItem*)));
+  connect (m_part, TQ_SIGNAL(itemsAdded(const KFileItemList&)),
+           TQ_SLOT (slotItemsAdded(const KFileItemList&)));
+  connect (m_part, TQ_SIGNAL(itemsFilteredByMime(const KFileItemList&)),
+           TQ_SLOT (slotItemsAdded(const KFileItemList&)));
+  connect (m_part, TQ_SIGNAL(itemsRefresh(const KFileItemList&)),
+           TQ_SLOT (slotItemsRefresh(const KFileItemList&)));
+  connect (m_part, TQ_SIGNAL(aboutToOpenURL()), TQ_SLOT(slotOpenURL()));
 
   // add a searchline filter for konqis icons/list views
   TQHBox *hbox = new TQHBox(m_part->widget());
@@ -179,12 +179,12 @@ DirFilterPlugin::DirFilterPlugin (TQObject* parent, const char* name,
 
   clear->setWhatsThis(i18n("Clear filter field<p>Clears the content of the filter field."));
 
-  if ( ::tqqt_cast<TDEListView*>(m_part->scrollWidget()) )
+  if ( ::tqt_cast<TDEListView*>(m_part->scrollWidget()) )
   {
     m_searchWidget = new TDEListViewSearchLine(hbox);
     static_cast<TDEListViewSearchLine*>(m_searchWidget)->setListView(static_cast<TDEListView*>(m_part->scrollWidget()));
   }
-  else if ( ::tqqt_cast<TQIconView*>(m_part->scrollWidget()) )
+  else if ( ::tqt_cast<TQIconView*>(m_part->scrollWidget()) )
   {
     m_searchWidget = new TDEIconViewSearchLine(hbox);
     static_cast<TDEIconViewSearchLine*>(m_searchWidget)->setIconView(static_cast<TQIconView*>(m_part->scrollWidget()));
@@ -197,8 +197,8 @@ DirFilterPlugin::DirFilterPlugin (TQObject* parent, const char* name,
   if ( m_searchWidget )
   {
     TQWhatsThis::add(m_searchWidget, i18n("Enter here a text which an item in the view must contain anywhere to be shown."));
-    connect(clear, TQT_SIGNAL(activated()), m_searchWidget, TQT_SLOT(clear()));
-    connect(m_searchWidget, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(searchTextChanged(const TQString&)));
+    connect(clear, TQ_SIGNAL(activated()), m_searchWidget, TQ_SLOT(clear()));
+    connect(m_searchWidget, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(searchTextChanged(const TQString&)));
   }
 
   KWidgetAction *filterAction = new KWidgetAction(hbox, i18n("Filter Field"),
@@ -210,9 +210,9 @@ DirFilterPlugin::DirFilterPlugin (TQObject* parent, const char* name,
 // Really the broken TQt3 iconview should just be modified to include a hidden list; it would make things *so* much easier!
   m_refreshTimer = new TQTimer( this );
   m_reactivateRefreshTimer = new TQTimer( this );
-  connect( m_refreshTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(activateSearch()) );
+  connect( m_refreshTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(activateSearch()) );
   m_refreshTimer->start( 200, FALSE ); // 200 millisecond continuous timer
-  connect( m_reactivateRefreshTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(reactivateRefreshTimer()) );
+  connect( m_reactivateRefreshTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(reactivateRefreshTimer()) );
 
 }
 
@@ -302,7 +302,7 @@ void DirFilterPlugin::slotShowPopup()
 
     m_pMimeInfo[it.key()].id = m_pFilterMenu->popupMenu()->insertItem (
                                SmallIconSet(it.data().iconName), label,
-                               this, TQT_SLOT(slotItemSelected(int)), 0, ++id);
+                               this, TQ_SLOT(slotItemSelected(int)), 0, ++id);
 
     if (it.data().useAsFilter)
     {
@@ -333,7 +333,7 @@ void DirFilterPlugin::slotShowPopup()
 
       m_pMimeInfo[(*it)].id = m_pFilterMenu->popupMenu()->insertItem (
                               SmallIconSet(m_pMimeInfo[(*it)].iconName), label,
-                              this, TQT_SLOT(slotItemSelected(int)), 0, ++id);
+                              this, TQ_SLOT(slotItemSelected(int)), 0, ++id);
 
       if (m_pMimeInfo[(*it)].useAsFilter)
       {
@@ -345,16 +345,16 @@ void DirFilterPlugin::slotShowPopup()
 
   m_pFilterMenu->popupMenu()->insertSeparator ();
   id = m_pFilterMenu->popupMenu()->insertItem (i18n("Use Multiple Filters"),
-                                               this, TQT_SLOT(slotMultipleFilters()));
+                                               this, TQ_SLOT(slotMultipleFilters()));
   m_pFilterMenu->popupMenu()->setItemEnabled (id, enableReset <= 1);
   m_pFilterMenu->popupMenu()->setItemChecked (id, SessionManager::self()->useMultipleFilters);
 
   id = m_pFilterMenu->popupMenu()->insertItem (i18n("Show Count"), this,
-                                               TQT_SLOT(slotShowCount()));
+                                               TQ_SLOT(slotShowCount()));
   m_pFilterMenu->popupMenu()->setItemChecked (id, SessionManager::self()->showCount);
 
   id = m_pFilterMenu->popupMenu()->insertItem (i18n("Reset"), this,
-                                               TQT_SLOT(slotReset()));
+                                               TQ_SLOT(slotReset()));
 
   m_pFilterMenu->popupMenu()->setItemEnabled (id, enableReset);
 }
@@ -463,7 +463,7 @@ void DirFilterPlugin::slotItemRemoved(const KFileItem* item)
 	// NOTE: This bug is NOT present in qlistviewitem
 
 	// HACK around it here...
-	if ( ::tqqt_cast<TQIconView*>(m_part->scrollWidget()) ) {
+	if ( ::tqt_cast<TQIconView*>(m_part->scrollWidget()) ) {
 		static_cast<TDEIconViewSearchLine*>(m_searchWidget)->iconDeleted(item->name());
 	}
 
@@ -481,7 +481,7 @@ void DirFilterPlugin::slotItemRemoved(const KFileItem* item)
 				m_part->setMimeFilter(filters);
 				SessionManager::self()->save(m_part->url(), filters);
 				// Use 1ms delay to avoid possible race conditions
-				TQTimer::singleShot(1, this, TQT_SLOT(slotTimeout()));
+				TQTimer::singleShot(1, this, TQ_SLOT(slotTimeout()));
 			}
 			m_pMimeInfo.remove(mimeType);
 		}
@@ -495,27 +495,27 @@ void DirFilterPlugin::slotItemsRefresh(const KFileItemList &list)
     m_pFilterMenu->setEnabled (m_part->nameFilter().isEmpty());
     return;
   }
-  if ( ::tqqt_cast<TDEListView*>(m_part->scrollWidget()) )
+  if ( ::tqt_cast<TDEListView*>(m_part->scrollWidget()) )
   {
     static_cast<TDEListViewSearchLine*>(m_searchWidget)->updateSearch();
   }
-  else if ( ::tqqt_cast<TQIconView*>(m_part->scrollWidget()) )
+  else if ( ::tqt_cast<TQIconView*>(m_part->scrollWidget()) )
   {
     static_cast<TDEIconViewSearchLine*>(m_searchWidget)->updateSearch();
   }
     
   TQMap<TQString,bool> itemsMap;
-  if (::tqqt_cast<TDEListView*>(m_part->scrollWidget()))
+  if (::tqt_cast<TDEListView*>(m_part->scrollWidget()))
   {
-    TQListView *listview = ::tqqt_cast<TDEListView*>(m_part->scrollWidget());
+    TQListView *listview = ::tqt_cast<TDEListView*>(m_part->scrollWidget());
     for (TQListViewItemIterator lv_it(listview); lv_it.current(); ++lv_it)
     {
       itemsMap.insert(lv_it.current()->text(0), false);   
     }
   }
-  else if ( ::tqqt_cast<TQIconView*>(m_part->scrollWidget()) )
+  else if ( ::tqt_cast<TQIconView*>(m_part->scrollWidget()) )
   {
-    TQIconView *iconview = ::tqqt_cast<TQIconView*>(m_part->scrollWidget());
+    TQIconView *iconview = ::tqt_cast<TQIconView*>(m_part->scrollWidget());
     for (TQIconViewItem *item = iconview->firstItem(); item; item = item->nextItem())
     {
       itemsMap.insert(item->text(), false);   
@@ -547,7 +547,7 @@ void DirFilterPlugin::slotItemsRefresh(const KFileItemList &list)
         m_part->setMimeFilter(filters);
         SessionManager::self()->save(m_part->url(), filters);
         // Use 1ms delay to avoid possible race conditions
-        TQTimer::singleShot(1, this, TQT_SLOT(slotTimeout()));
+        TQTimer::singleShot(1, this, TQ_SLOT(slotTimeout()));
       }
       MimeInfoIterator del_mit = it;
       ++it;
@@ -599,10 +599,10 @@ void DirFilterPlugin::activateSearch()
 
 	m_oldFilterString = m_searchWidget->text();
 
-	if ( ::tqqt_cast<TDEListView*>(m_part->scrollWidget()) ) {
+	if ( ::tqt_cast<TDEListView*>(m_part->scrollWidget()) ) {
 		static_cast<TDEListViewSearchLine*>(m_searchWidget)->updateSearch();
 	}
-	else if ( ::tqqt_cast<TQIconView*>(m_part->scrollWidget()) ) {
+	else if ( ::tqt_cast<TQIconView*>(m_part->scrollWidget()) ) {
 		static_cast<TDEIconViewSearchLine*>(m_searchWidget)->updateSearch();
 	}
 }
