@@ -138,7 +138,7 @@ FFRS::FFRS() : TQObject(), Plugin()
 	dpyleft = dpyright = 0;
 	changed();
 	prefs = new FFRSPrefs(this);
-	connect(prefs, TQT_SIGNAL(changed()), TQT_SLOT(changed()));
+	connect(prefs, TQ_SIGNAL(changed()), TQ_SLOT(changed()));
 
 	setSamples(256);
 
