@@ -18,7 +18,7 @@ extern "C"
 
 NexPlugin::NexPlugin()
 {
-	connect(&process, TQT_SIGNAL(processExited(TDEProcess *)), this, TQT_SLOT(processExited(TDEProcess *)));
+	connect(&process, TQ_SIGNAL(processExited(TDEProcess *)), this, TQ_SLOT(processExited(TDEProcess *)));
 }
 
 NexPlugin::~NexPlugin()
