@@ -30,10 +30,10 @@ extern "C"
 Madness::Madness()
 	: MonoFFTScope(100), Plugin(), mWm(this)
 {
-	connect(&mWm, TQT_SIGNAL(currentDesktopChanged(int)), TQT_SLOT(update()));
-	connect(&mWm, TQT_SIGNAL(windowAdded(WId)), TQT_SLOT(update()));
-	connect(&mWm, TQT_SIGNAL(windowRemoved(WId)), TQT_SLOT(update()));
-	connect(&mWm, TQT_SIGNAL(strutChanged()), TQT_SLOT(update()));
+	connect(&mWm, TQ_SIGNAL(currentDesktopChanged(int)), TQ_SLOT(update()));
+	connect(&mWm, TQ_SIGNAL(windowAdded(WId)), TQ_SLOT(update()));
+	connect(&mWm, TQ_SIGNAL(windowRemoved(WId)), TQ_SLOT(update()));
+	connect(&mWm, TQ_SIGNAL(strutChanged()), TQ_SLOT(update()));
 
 }
 
